pub struct Framebuffer {
pub ptr: *mut u8,
pub size: usize,
pub stride: usize,
pub pixel_format: PixelFormat,
pub width: usize,
pub height: usize,
pub bytes_per_pixel: usize,
}Expand description
Metadata that describes a framebuffer.
Fields
ptr: *mut u8size: usizeThe total size of the framebuffer in bytes.
stride: usizeThe number of pixels in each row of the framebuffer.
pixel_format: PixelFormatPixel format of the framebuffer.
width: usizeWidth of the framebuffer in pixels.
height: usizeHeight of the framebuffer in pixels.
bytes_per_pixel: usizeBytes each pixel will take on the framebuffer.
Implementations
Sourceimpl Framebuffer
impl Framebuffer
Sourcepub fn draw_pixel(&self, x: usize, y: usize, color: Color)
pub fn draw_pixel(&self, x: usize, y: usize, color: Color)
Draws a single pixel at (x, y).
This panics if the coordinates are outside the framebuffer bounds.